#! /bin/sh
#  ------------------------------------------------------------
#  Company: Software- und Organisations-Service GmbH
#  Purpose: Watchdog script for JS7 Agent
#  ------------------------------------------------------------

set -e
JS7_AGENT_EXIT=0

start_agent() 
{
  HTTPS_PORT_OPTION=""
  test -z "${JS7_AGENT_HTTPS_PORT}" || HTTPS_PORT_OPTION="--https-port=${JS7_AGENT_HTTPS_PORT}"
  KILL_SCRIPT_OPTION=""
  test -z "${JS7_AGENT_KILL_SCRIPT}" || KILL_SCRIPT_OPTION="--kill-script="${JS7_AGENT_KILL_SCRIPT}""
  
  #test -d "${JS7_AGENT_DATA}/work" && (rm -rf "${JS7_AGENT_DATA}/work" 2>/dev/null || true)
  #test -d "${JS7_AGENT_DATA}/work" || mkdir -p "${JS7_AGENT_DATA}/work" 2>/dev/null || true
  
  "${JAVABIN}" -DJS7.Agent="${JS7_AGENT_PORT}" ${JS7_AGENT_JAVA_OPTIONS} ${LMAX_JAVA_OPTIONS} -classpath "${JS7_AGENT_CLASSPATH}" js7.agent.main.AgentMain --http-port="${JS7_AGENT_HTTP_PORT}" ${HTTPS_PORT_OPTION} ${KILL_SCRIPT_OPTION} --config-directory="${JS7_AGENT_CONFIG_DIR}" --data-directory="${JS7_AGENT_DATA}" --job-working-directory="${JS7_AGENT_WORK_DIR}" > "${JS7_AGENT_LOGS}/watchdog.log" 2>&1 &
  JS7_AGENT_EXIT=$?
  
  if [ "${JS7_AGENT_EXIT}" = "0" ]
  then
    create_pid_file $!
    JS7_AGENT_PID=$!
    echo "...JS7 Agent(${JS7_AGENT_PORT}) is started with pid=${JS7_AGENT_PID}!"
    echo "...see log file ${JS7_AGENT_LOGS}/agent.log"
    echo "...watchdog for pid ${JS7_AGENT_PID} is started"
    echo "Hit ENTER to return to command prompt."
    wait "${JS7_AGENT_PID}" 2>/dev/null || JS7_AGENT_EXIT=$?
  fi
  
  echo "...JS7 Agent watchdog terminates with exit code ${JS7_AGENT_EXIT}" >> "${JS7_AGENT_LOGS}/watchdog.log"
  
  if [ "${JS7_AGENT_EXIT}" != "0" ] && [ -s "${JS7_AGENT_CRASH_FILE}" ] 
  then
    echo "Executing crash kill script \"${JS7_AGENT_CRASH_FILE}\""
    cat "${JS7_AGENT_CRASH_FILE}" || true
    /bin/sh "${JS7_AGENT_CRASH_FILE}" > "${KILL_TASK_LOG_FILE}" 2>&1 || true
  fi
  
  rm "${JS7_AGENT_PID_FILE}" >/dev/null 2>/dev/null || true
  
  #abort and restart
  if [ "${JS7_AGENT_EXIT}" = "98" ]
  then
    start_agent
  fi
  #terminate and restart
  if [ "${JS7_AGENT_EXIT}" = "97" ]
  then
    start_agent
  fi 
}

create_pid_file() 
{
  JS7_AGENT_PID=$1
  echo "${JS7_AGENT_PID}" > "${JS7_AGENT_PID_FILE}" || true
  if [ ! -f "${JS7_AGENT_PID_FILE}" ]
  then
    echo "...could not create pid file: \"${JS7_AGENT_PID_FILE}\""
    echo "...please check permissions for directory: \"${JS7_AGENT_PID_FILE_DIR}\"."
    exit 3
  else
    chmod 666 "${JS7_AGENT_PID_FILE}" 2>/dev/null || true
  fi 
}

start_agent
set +e
exit ${JS7_AGENT_EXIT}